[−][src]Crate asyncgit
asyncgit
Re-exports
pub use crate::sync::diff::DiffLine; |
pub use crate::sync::diff::DiffLineType; |
pub use crate::sync::diff::FileDiff; |
pub use crate::sync::status::StatusItem; |
pub use crate::sync::status::StatusItemType; |
Modules
| cached | cached lookups: parts of the sync api that might take longer to compute but change seldom so doing them async might be overkill |
| sync | sync git api |
Structs
| AsyncCommitFiles | |
| AsyncDiff | |
| AsyncLog | |
| AsyncStatus | |
| AsyncTags | |
| DiffParams | |
| StatusParams |
Enums
| AsyncNotification | this type is used to communicate events back through the channel |
| DiffType | |
| FetchStatus |
Statics
| CWD | current working director |
Functions
| hash | helper function to calculate the hash of an arbitrary type that implements the |